@@ -4,36 +4,10 @@ module FakeFS
     attr_accessor :name, :parent, :mtime, :atime, :mode, :uid, :gid
     attr_reader :ctime, :birthtime
 
-    # Inode class
-    class Inode
-      def initialize(file_owner)
-        @content = ''.encode(Encoding.default_external)
-        @links = [file_owner]
-      end
-
-      attr_accessor :content
-      attr_accessor :links
-
-      def link(file)
-        links << file unless links.include?(file)
-        file.inode = self
-      end
-
-      def unlink(file)
-        links.delete(file)
-      end
-
-      def clone
-        clone = super
-        clone.content = content.dup
-        clone
-      end
-    end
-
     def initialize(name = nil, parent = nil)
       @name      = name
       @parent    = parent
-      @inode     = Inode.new(self)
+      @inode     = FakeInode.new(self)
       @ctime     = Time.now
       @mtime     = @ctime
       @atime     = @ctime
@@ -83,6 +57,7 @@ module FakeFS
 
     def delete
       inode.unlink(self)
+      inode.free_inode_num
       parent.delete(self)
     end
   end
