@@ -20,13 +20,13 @@ module FakeFS
       fs.entries
     end
 
-    def find(path)
+    def find(path, find_flags = 0, gave_char_class = false)
       parts = path_parts(normalize_path(path))
       return fs if parts.empty? # '/'
 
       entries = Globber.expand(path).flat_map do |pattern|
         parts = path_parts(normalize_path(pattern))
-        find_recurser(fs, parts).flatten
+        find_recurser(fs, parts, find_flags, gave_char_class).flatten
       end
 
       case entries.length
@@ -85,11 +85,12 @@ module FakeFS
 
     def chdir(dir, &blk)
       new_dir = find(dir)
-      dir_levels.push dir if blk
+      dir_levels.push dir.to_s if blk
 
-      raise Errno::ENOENT, dir unless new_dir
+      raise Errno::ENOENT, dir.to_s unless new_dir
+      raise Errno::ENOTDIR, dir.to_s unless File.directory? new_dir
 
-      dir_levels.push dir unless blk
+      dir_levels.push dir.to_s unless blk
       yield(dir) if blk
     ensure
       dir_levels.pop if blk
@@ -116,9 +117,9 @@ module FakeFS
 
     private
 
-    def find_recurser(dir, parts)
+    def find_recurser(dir, parts, find_flags = 0, gave_char_class = false)
       return [] unless dir.respond_to? :[]
-      pattern, *parts = parts # rubocop:disable Lint/ShadowedArgument
+      pattern, *parts = parts
       matches =
         case pattern
         when '**'
@@ -139,14 +140,14 @@ module FakeFS
           end
         else
           Globber.expand(pattern).flat_map do |subpattern|
-            dir.matches(Globber.regexp(subpattern))
+            dir.matches(Globber.regexp(subpattern, find_flags, gave_char_class))
           end
         end
 
       if parts.empty? # we're done recursing
         matches
       else
-        matches.map { |entry| find_recurser(entry, parts) }
+        matches.map { |entry| find_recurser(entry, parts, find_flags, gave_char_class) }
       end
     end
 
