@@ -36,8 +36,6 @@ module FakeFS
       if /\0/ =~ @path
         raise ArgumentError, "pathname contains \\0: #{@path.inspect}"
       end
-
-      taint if @path.tainted?
     end
 
     def freeze
@@ -46,18 +44,6 @@ module FakeFS
       self
     end
 
-    def taint
-      super
-      @path.taint
-      self
-    end
-
-    def untaint
-      super
-      @path.untaint
-      self
-    end
-
     #
     # Compare this pathname with +other+.  The comparison is string-based.
     # Be aware that two different paths
