@@ -1,4 +1,4 @@
-require 'test_helper'
+require_relative 'test_helper'
 
 # Kernel test class
 class KernelTest < Minitest::Test
@@ -40,12 +40,16 @@ class KernelTest < Minitest::Test
 
       begin
         open('/tmp/a').read
-      rescue => e
+      rescue StandardError => e
         raise e
       end
     end
   end
 
+  def test_kernel_open_remains_private
+    refute 'foo'.respond_to?(:open), 'String#open should be private'
+  end
+
   def test_can_exec_normally2
     out = open("|echo 'foo'")
     assert_equal "foo\n", out.gets
